@@ -20,19 +20,12 @@
 
 package org.videolan.vlc;
 
-import java.io.File;
-import java.io.FileFilter;
-import java.io.IOException;
-import java.lang.Thread.State;
-import java.util.ArrayList;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.LinkedList;
-import java.util.List;
-import java.util.Locale;
-import java.util.Stack;
-import java.util.concurrent.locks.ReadWriteLock;
-import java.util.concurrent.locks.ReentrantReadWriteLock;
+import android.content.Context;
+import android.os.Environment;
+import android.os.Handler;
+import android.os.Message;
+import android.text.TextUtils;
+import android.util.Log;
 
 import org.videolan.libvlc.LibVLC;
 import org.videolan.libvlc.Media;
@@ -44,12 +37,21 @@ import org.videolan.vlc.util.Util;
 import org.videolan.vlc.util.VLCInstance;
 import org.videolan.vlc.util.WeakHandler;
 
-import android.content.Context;
-import android.os.Environment;
-import android.os.Handler;
-import android.os.Message;
-import android.text.TextUtils;
-import android.util.Log;
+import java.io.File;
+import java.io.FileFilter;
+import java.io.IOException;
+import java.lang.Thread.State;
+import java.lang.ref.WeakReference;
+import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.LinkedList;
+import java.util.List;
+import java.util.Locale;
+import java.util.Map;
+import java.util.Stack;
+import java.util.concurrent.locks.ReadWriteLock;
+import java.util.concurrent.locks.ReentrantReadWriteLock;
 
 public class MediaLibrary {
     public final static String TAG = "VLC/MediaLibrary";
@@ -63,7 +65,7 @@ public class MediaLibrary {
     private boolean isStopping = false;
     private boolean mRestart = false;
     protected Thread mLoadingThread;
-    private IBrowser mBrowser = null;
+    private WeakReference<IBrowser> mBrowser = null;
 
     public final static HashSet<String> FOLDER_BLACKLIST;
     static {
@@ -81,7 +83,7 @@ public class MediaLibrary {
 
         FOLDER_BLACKLIST = new HashSet<String>();
         for (String item : folder_blacklist)
-            FOLDER_BLACKLIST.add(android.os.Environment.getExternalStorageDirectory().getPath() + item);
+            FOLDER_BLACKLIST.add(AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY + item);
     }
 
     private MediaLibrary() {
@@ -91,7 +93,7 @@ public class MediaLibrary {
         mItemListLock = new ReentrantReadWriteLock();
     }
 
-    public void loadMediaItems(Context context, boolean restart) {
+    public void loadMediaItems(boolean restart) {
         if (restart && isWorking()) {
             /* do a clean restart if a scan is ongoing */
             mRestart = true;
@@ -194,6 +196,8 @@ public class MediaLibrary {
         String[] items, playlistNames = db.getPlaylists();
         for (String playlistName : playlistNames){
             items = db.playlistGetItems(playlistName);
+            if (items == null)
+                continue;
             playList = new AudioBrowserListAdapter.ListItem(playlistName, null, null, false);
             for (String track : items){
                 playList.mMediaList.add(new MediaWrapper(track));
@@ -245,8 +249,8 @@ public class MediaLibrary {
             final MediaDatabase mediaDatabase = MediaDatabase.getInstance();
 
             // show progressbar in footer
-            if (mBrowser != null)
-                mBrowser.showProgressBar();
+            if (mBrowser != null && mBrowser.get() != null)
+                mBrowser.get().showProgressBar();
 
             List<File> mediaDirs = mediaDatabase.getMediaDirs();
             if (mediaDirs.size() == 0) {
@@ -334,8 +338,10 @@ public class MediaLibrary {
 
                 //Remove ignored files
                 HashSet<String> mediasToRemove = new HashSet<String>();
+                String path;
                 outloop:
-                for (String path : existingMedias.keySet()){
+                for (Map.Entry<String, MediaWrapper> entry : existingMedias.entrySet()){
+                    path = entry.getKey();
                     for (String dirPath : dirsToIgnore) {
                         if (path.startsWith(dirPath)) {
                             mediasToRemove.add(path);
@@ -349,9 +355,9 @@ public class MediaLibrary {
                 // Process the stacked items
                 for (File file : mediaToScan) {
                     String fileURI = LibVLC.PathToURI(file.getPath());
-                    if (mBrowser != null)
-                        mBrowser.sendTextInfo(file.getName(), count,
-                            mediaToScan.size());
+                    if (mBrowser != null && mBrowser.get() != null)
+                        mBrowser.get().sendTextInfo(file.getName(), count,
+                                mediaToScan.size());
                     count++;
                     if (existingMedias.containsKey(fileURI)) {
                         /**
@@ -412,9 +418,9 @@ public class MediaLibrary {
                 }
 
                 // hide progressbar in footer
-                if (mBrowser != null) {
-                    mBrowser.clearTextInfo();
-                    mBrowser.hideProgressBar();
+                if (mBrowser != null && mBrowser.get() != null) {
+                    mBrowser.get().clearTextInfo();
+                    mBrowser.get().hideProgressBar();
                 }
 
                 Util.actionScanStop();
@@ -470,6 +476,9 @@ public class MediaLibrary {
     }
 
     public void setBrowser(IBrowser browser) {
-        mBrowser = browser;
+        if (browser != null)
+            mBrowser = new WeakReference<IBrowser>(browser);
+        else
+            mBrowser.clear();
     }
 }
