@@ -58,7 +58,6 @@ import android.widget.Toast;
 
 import org.videolan.libvlc.EventHandler;
 import org.videolan.libvlc.LibVLC;
-import org.videolan.libvlc.LibVlcException;
 import org.videolan.libvlc.LibVlcUtil;
 import org.videolan.libvlc.Media;
 import org.videolan.vlc.BuildConfig;
@@ -70,6 +69,7 @@ import org.videolan.vlc.R;
 import org.videolan.vlc.RemoteControlClientReceiver;
 import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.gui.MainActivity;
+import org.videolan.vlc.gui.AudioPlayerContainerActivity;
 import org.videolan.vlc.gui.audio.AudioUtil;
 import org.videolan.vlc.gui.video.VideoPlayerActivity;
 import org.videolan.vlc.interfaces.IAudioService;
@@ -119,6 +119,7 @@ public class AudioService extends Service {
 
     private LibVLC mLibVLC;
     private MediaWrapperListPlayer mMediaListPlayer;
+    private boolean mForceAudio = false;
     private HashMap<IAudioServiceCallback, Integer> mCallback;
     private EventHandler mEventHandler;
     private OnAudioFocusChangeListener audioFocusListener;
@@ -180,7 +181,7 @@ public class AudioService extends Service {
 
         // Make sure the audio player will acquire a wake-lock while playing. If we don't do
         // that, the CPU might go to sleep while the song is playing, causing playback to stop.
-        PowerManager pm = (PowerManager) getSystemService(Context.POWER_SERVICE);
+        PowerManager pm = (PowerManager) VLCApplication.getAppContext().getSystemService(Context.POWER_SERVICE);
         mWakeLock = pm.newWakeLock(PowerManager.PARTIAL_WAKE_LOCK, TAG);
 
         IntentFilter filter = new IntentFilter();
@@ -227,7 +228,7 @@ public class AudioService extends Service {
     @TargetApi(Build.VERSION_CODES.ICE_CREAM_SANDWICH)
     public void setUpRemoteControlClient() {
         Context context = VLCApplication.getAppContext();
-        AudioManager audioManager = (AudioManager)context.getSystemService(AUDIO_SERVICE);
+        AudioManager audioManager = (AudioManager)VLCApplication.getAppContext().getSystemService(AUDIO_SERVICE);
 
         if (LibVlcUtil.isICSOrLater()) {
             audioManager.registerMediaButtonEventReceiver(mRemoteControlClientReceiverComponent);
@@ -349,7 +350,7 @@ public class AudioService extends Service {
             };
         }
 
-        AudioManager am = (AudioManager)getSystemService(AUDIO_SERVICE);
+        AudioManager am = (AudioManager)VLCApplication.getAppContext().getSystemService(AUDIO_SERVICE);
         if(gain)
             am.requestAudioFocus(audioFocusListener, AudioManager.STREAM_MUSIC, AudioManager.AUDIOFOCUS_GAIN);
         else
@@ -385,7 +386,7 @@ public class AudioService extends Service {
             }
 
             // skip all headsets events if there is a call
-            TelephonyManager telManager = (TelephonyManager) getSystemService(Context.TELEPHONY_SERVICE);
+            TelephonyManager telManager = (TelephonyManager) VLCApplication.getAppContext().getSystemService(Context.TELEPHONY_SERVICE);
             if (telManager != null && telManager.getCallState() != TelephonyManager.CALL_STATE_IDLE)
                 return;
 
@@ -618,7 +619,7 @@ public class AudioService extends Service {
     };
 
     private void handleVout() {
-        if (mLibVLC.getVideoTracksCount() <= 0 || !hasCurrentMedia())
+        if (mForceAudio || mLibVLC.getVideoTracksCount() <= 0 || !hasCurrentMedia())
             return;
         final MediaWrapper mw = mMediaListPlayer.getMediaList().getMedia(mCurrentIndex);
         if (mw == null)
@@ -751,7 +752,7 @@ public class AudioService extends Service {
                 .setDeleteIntent(piStop);
 
             Intent notificationIntent = new Intent(this, MainActivity.class);
-            notificationIntent.setAction(MainActivity.ACTION_SHOW_PLAYER);
+            notificationIntent.setAction(AudioPlayerContainerActivity.ACTION_SHOW_PLAYER);
             notificationIntent.addCategory(Intent.CATEGORY_LAUNCHER);
             notificationIntent.putExtra(START_FROM_NOTIFICATION, true);
             PendingIntent pendingIntent = PendingIntent.getActivity(this, 0, notificationIntent, PendingIntent.FLAG_UPDATE_CURRENT);
@@ -1202,24 +1203,16 @@ public class AudioService extends Service {
          * @throws RemoteException
          */
         @Override
-        public void load(List<String> mediaPathList, int position)
+        public void loadLocations(List<String> mediaPathList, int position)
                 throws RemoteException {
-
-            Log.v(TAG, "Loading position " + ((Integer)position).toString() + " in " + mediaPathList.toString());
-            mEventHandler.addHandler(mVlcEventHandler);
-
-            mMediaListPlayer.getMediaList().removeEventListener(mListEventListener);
-            mMediaListPlayer.getMediaList().clear();
-            MediaWrapperList mediaList = mMediaListPlayer.getMediaList();
-
-            mPrevious.clear();
-
+            ArrayList<MediaWrapper> mediaList = new ArrayList<MediaWrapper>();
             MediaDatabase db = MediaDatabase.getInstance();
+
             for (int i = 0; i < mediaPathList.size(); i++) {
                 String location = mediaPathList.get(i);
                 MediaWrapper mediaWrapper = db.getMedia(location);
-                if(mediaWrapper == null) {
-                    if(!validateLocation(location)) {
+                if (mediaWrapper == null) {
+                    if (!validateLocation(location)) {
                         Log.w(TAG, "Invalid location " + location);
                         showToast(getResources().getString(R.string.invalid_location, location), Toast.LENGTH_SHORT);
                         continue;
@@ -1232,6 +1225,26 @@ public class AudioService extends Service {
                 }
                 mediaList.add(mediaWrapper);
             }
+            load(mediaList, position, false);
+        }
+
+        @Override
+        public void load(List<MediaWrapper> mediaList, int position, boolean forceAudio)
+                throws RemoteException {
+
+            Log.v(TAG, "Loading position " + ((Integer) position).toString() + " in " + mediaList.toString());
+            mEventHandler.addHandler(mVlcEventHandler);
+
+            mMediaListPlayer.getMediaList().removeEventListener(mListEventListener);
+            mMediaListPlayer.getMediaList().clear();
+            MediaWrapperList currentMediaList = mMediaListPlayer.getMediaList();
+
+            mPrevious.clear();
+            mForceAudio = forceAudio;
+
+            for (int i = 0; i < mediaList.size(); i++) {
+                currentMediaList.add(mediaList.get(i));
+            }
 
             if (mMediaListPlayer.getMediaList().size() == 0) {
                 Log.w(TAG, "Warning: empty media list, nothing to play !");
@@ -1319,28 +1332,15 @@ public class AudioService extends Service {
          * Append to the current existing playlist
          */
         @Override
-        public void append(List<String> mediaLocationList) throws RemoteException {
+        public void append(List<MediaWrapper> mediaList) throws RemoteException {
             if (!hasCurrentMedia())
             {
-                load(mediaLocationList, 0);
+                load(mediaList, 0, false);
                 return;
             }
 
-            MediaDatabase db = MediaDatabase.getInstance();
-            for (int i = 0; i < mediaLocationList.size(); i++) {
-                String location = mediaLocationList.get(i);
-                MediaWrapper mediaWrapper = db.getMedia(location);
-                if(mediaWrapper == null) {
-                    if (!validateLocation(location)) {
-                        showToast(getResources().getString(R.string.invalid_location, location), Toast.LENGTH_SHORT);
-                        continue;
-                    }
-                    Log.v(TAG, "Creating on-the-fly Media object for " + location);
-                    final Media media = new Media(mLibVLC, location);
-                    media.parse(); // FIXME: parse should'nt be done asynchronously
-                    media.release();
-                    mediaWrapper = new MediaWrapper(media);
-                }
+            for (int i = 0; i < mediaList.size(); i++) {
+                MediaWrapper mediaWrapper = mediaList.get(i);
                 mMediaListPlayer.getMediaList().add(mediaWrapper);
             }
             AudioService.this.saveMediaList();
@@ -1396,6 +1396,11 @@ public class AudioService extends Service {
             return mMediaListPlayer.getMediaList().getMRL(mCurrentIndex);
         }
 
+        @Override
+        public MediaWrapper getCurrentMediaWrapper() throws RemoteException {
+            return AudioService.this.getCurrentMedia();
+        }
+
         @Override
         public void next() throws RemoteException {
             AudioService.this.next();
@@ -1542,7 +1547,7 @@ public class AudioService extends Service {
         int position = Math.max(0, mediaPathList.indexOf(currentMedia));
         // load playlist
         try {
-            mInterface.load(mediaPathList, position);
+            mInterface.loadLocations(mediaPathList, position);
         } catch (RemoteException e) {
             e.printStackTrace();
         }
