@@ -22,10 +22,8 @@ package org.videolan.vlc.gui;
 
 import android.annotation.TargetApi;
 import android.app.SearchManager;
-import android.content.BroadcastReceiver;
 import android.content.Context;
 import android.content.Intent;
-import android.content.IntentFilter;
 import android.content.SharedPreferences;
 import android.content.SharedPreferences.Editor;
 import android.database.Cursor;
@@ -34,21 +32,16 @@ import android.os.Build;
 import android.os.Bundle;
 import android.os.Handler;
 import android.os.Message;
-import android.preference.PreferenceManager;
 import android.support.v4.app.Fragment;
 import android.support.v4.app.FragmentActivity;
 import android.support.v4.app.FragmentManager;
 import android.support.v4.app.FragmentTransaction;
 import android.support.v4.view.GravityCompat;
 import android.support.v4.view.MenuItemCompat;
-import android.support.v7.app.ActionBar;
 import android.support.v7.app.ActionBarDrawerToggle;
-import android.support.v7.app.AppCompatActivity;
 import android.support.v7.widget.SearchView;
-import android.support.v7.widget.Toolbar;
 import android.util.Log;
 import android.view.KeyEvent;
-import android.view.LayoutInflater;
 import android.view.Menu;
 import android.view.MenuInflater;
 import android.view.MenuItem;
@@ -68,31 +61,27 @@ import org.videolan.vlc.BuildConfig;
 import org.videolan.vlc.MediaDatabase;
 import org.videolan.vlc.MediaLibrary;
 import org.videolan.vlc.R;
+import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.audio.AudioService;
-import org.videolan.vlc.audio.AudioServiceController;
 import org.videolan.vlc.gui.SidebarAdapter.SidebarEntry;
 import org.videolan.vlc.gui.audio.AudioBrowserFragment;
-import org.videolan.vlc.gui.audio.AudioPlayer;
 import org.videolan.vlc.gui.browser.BaseBrowserFragment;
 import org.videolan.vlc.gui.browser.MediaBrowserFragment;
 import org.videolan.vlc.gui.browser.NetworkBrowserFragment;
+import org.videolan.vlc.gui.browser.StorageBrowserFragment;
 import org.videolan.vlc.gui.video.VideoGridFragment;
 import org.videolan.vlc.gui.video.VideoListAdapter;
 import org.videolan.vlc.gui.video.VideoPlayerActivity;
 import org.videolan.vlc.interfaces.IRefreshable;
 import org.videolan.vlc.interfaces.ISortable;
-import org.videolan.vlc.util.AndroidDevices;
 import org.videolan.vlc.util.Util;
 import org.videolan.vlc.util.VLCInstance;
 import org.videolan.vlc.util.WeakHandler;
 import org.videolan.vlc.widget.HackyDrawerLayout;
-import org.videolan.vlc.widget.SlidingPaneLayout;
 
-public class MainActivity extends AppCompatActivity implements OnItemClickListener, SearchSuggestionsAdapter.SuggestionDisplay, FilterQueryProvider {
+public class MainActivity extends AudioPlayerContainerActivity implements OnItemClickListener, SearchSuggestionsAdapter.SuggestionDisplay, FilterQueryProvider {
     public final static String TAG = "VLC/MainActivity";
 
-    public static final String ACTION_SHOW_PLAYER = "org.videolan.vlc.gui.ShowPlayer";
-
     private static final String PREF_FIRST_RUN = "first_run";
 
     private static final int ACTIVITY_RESULT_PREFERENCES = 1;
@@ -101,22 +90,18 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
     private static final int ACTIVITY_HIDE_PROGRESSBAR = 4;
     private static final int ACTIVITY_SHOW_TEXTINFO = 5;
 
-    private ActionBar mActionBar;
+    MediaLibrary mMediaLibrary;
+
     private SidebarAdapter mSidebarAdapter;
-    private AudioPlayer mAudioPlayer;
-    private AudioServiceController mAudioController;
-    private SlidingPaneLayout mSlidingPane;
-    private HackyDrawerLayout mRootContainer;
+    private HackyDrawerLayout mDrawerLayout;
     private ListView mListView;
     private ActionBarDrawerToggle mDrawerToggle;
 
     private View mInfoLayout;
     private ProgressBar mInfoProgress;
     private TextView mInfoText;
-    private View mAudioPlayerFilling;
     private String mCurrentFragment;
 
-    private SharedPreferences mSettings;
 
     private int mVersionNumber = -1;
     private boolean mFirstRun = false;
@@ -130,13 +115,6 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
 
     @Override
     protected void onCreate(Bundle savedInstanceState) {
-
-        /* Get settings */
-        mSettings = PreferenceManager.getDefaultSharedPreferences(this);
-
-        /* Theme must be applied before super.onCreate */
-        applyTheme();
-
         super.onCreate(savedInstanceState);
 
         if (!VLCInstance.testCompatibleCPU(this)) {
@@ -158,23 +136,21 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
         }
 
         /* Load media items from database and storage */
-        MediaLibrary.getInstance().loadMediaItems();
+        mMediaLibrary = MediaLibrary.getInstance();
+        mMediaLibrary.loadMediaItems();
 
         /*** Start initializing the UI ***/
 
         setContentView(R.layout.main);
 
-        Toolbar toolbar = (Toolbar) findViewById(R.id.main_toolbar);
-        setSupportActionBar(toolbar);
-
-        mSlidingPane = (SlidingPaneLayout) findViewById(R.id.pane);
-        mSlidingPane.setPanelSlideListener(mPanelSlideListener);
-
+        mDrawerLayout = (HackyDrawerLayout) findViewById(R.id.root_container);
         mListView = (ListView)findViewById(R.id.sidelist);
         mListView.setFooterDividersEnabled(true);
         mSidebarAdapter = new SidebarAdapter(this);
         mListView.setAdapter(mSidebarAdapter);
 
+        initAudioPlayerContainerActivity();
+
         if (savedInstanceState != null){
             mCurrentFragment = savedInstanceState.getString("current");
             if (mCurrentFragment != null)
@@ -186,15 +162,13 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
         mInfoLayout = findViewById(R.id.info_layout);
         mInfoProgress = (ProgressBar) findViewById(R.id.info_progress);
         mInfoText = (TextView) findViewById(R.id.info_text);
-        mAudioPlayerFilling = findViewById(R.id.audio_player_filling);
-        mRootContainer = (HackyDrawerLayout) findViewById(R.id.root_container);
 
         /* Set up the action bar */
         prepareActionBar();
 
         /* Set up the sidebar click listener
          * no need to invalidate menu for now */
-        mDrawerToggle = new ActionBarDrawerToggle(this, mRootContainer, R.string.drawer_open, R.string.drawer_close){
+        mDrawerToggle = new ActionBarDrawerToggle(this, mDrawerLayout, R.string.drawer_open, R.string.drawer_close){
             @Override
             public void onDrawerClosed(View drawerView) {
                 super.onDrawerClosed(drawerView);
@@ -204,21 +178,12 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
         };
 
         // Set the drawer toggle as the DrawerListener
-        mRootContainer.setDrawerListener(mDrawerToggle);
+        mDrawerLayout.setDrawerListener(mDrawerToggle);
         // set a custom shadow that overlays the main content when the drawer opens
-        mRootContainer.setDrawerShadow(R.drawable.drawer_shadow, GravityCompat.START);
+        mDrawerLayout.setDrawerShadow(R.drawable.drawer_shadow, GravityCompat.START);
 
         mListView.setOnItemClickListener(this);
 
-        /* Set up the audio player */
-        mAudioPlayer = new AudioPlayer();
-        mAudioPlayer.setUserVisibleHint(false);
-        mAudioController = AudioServiceController.getInstance();
-
-        getSupportFragmentManager().beginTransaction()
-            .replace(R.id.audio_player, mAudioPlayer)
-            .commit();
-
         if (mFirstRun) {
             /*
              * The sliding menu is automatically opened when the user closes
@@ -228,27 +193,15 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
             mHandler.postDelayed(new Runnable() {
                 @Override
                 public void run() {
-                    mRootContainer.openDrawer(mListView);
+                    mDrawerLayout.openDrawer(mListView);
                 }
             }, 500);
         }
 
-        /* Prepare the progressBar */
-        IntentFilter filter = new IntentFilter();
-        filter.addAction(ACTION_SHOW_PLAYER);
-        registerReceiver(messageReceiver, filter);
-
         /* Reload the latest preferences */
         reloadPreferences();
     }
 
-    private void applyTheme() {
-        boolean enableBlackTheme = mSettings.getBoolean("enable_black_theme", false);
-        if (enableBlackTheme) {
-            setTheme(R.style.Theme_VLC_Black);
-        }
-    }
-
 
     @Override
     protected void onPostCreate(Bundle savedInstanceState) {
@@ -259,7 +212,6 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
 
     @TargetApi(Build.VERSION_CODES.HONEYCOMB)
     private void prepareActionBar() {
-        mActionBar = getSupportActionBar();
         mActionBar.setDisplayHomeAsUpEnabled(true);
         mActionBar.setHomeButtonEnabled(true);
     }
@@ -267,8 +219,6 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
     @Override
     protected void onResume() {
         super.onResume();
-        mAudioController.addAudioPlayer(mAudioPlayer);
-        AudioServiceController.getInstance().bindAudioService(this);
 
         /* FIXME: this is used to avoid having MainActivity twice in the backstack */
         if (getIntent().hasExtra(AudioService.START_FROM_NOTIFICATION))
@@ -277,7 +227,7 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
 
         /* Load media items from database and storage */
         if (mScanNeeded)
-            MediaLibrary.getInstance().loadMediaItems();
+            mMediaLibrary.loadMediaItems();
         if (mSlidingPane.getState() == mSlidingPane.STATE_CLOSED)
             mActionBar.hide();
    }
@@ -331,16 +281,14 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
         super.onPause();
 
         /* Check for an ongoing scan that needs to be resumed during onResume */
-        mScanNeeded = MediaLibrary.getInstance().isWorking();
+        mScanNeeded = mMediaLibrary.isWorking();
         /* Stop scanning for files */
-        MediaLibrary.getInstance().stop();
+        mMediaLibrary.stop();
         /* Save the tab status in pref */
-        SharedPreferences.Editor editor = getSharedPreferences("MainActivity", MODE_PRIVATE).edit();
+        SharedPreferences.Editor editor = mSettings.edit();
         editor.putString("fragment", mCurrentFragment);
         Util.commitPreferences(editor);
 
-        mAudioController.removeAudioPlayer(mAudioPlayer);
-        AudioServiceController.getInstance().unbindAudioService(this);
         mFocusedPrior = 0;
     }
 
@@ -349,15 +297,6 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
         outState.putString("current", mCurrentFragment);
     }
 
-    @Override
-    protected void onDestroy() {
-        super.onDestroy();
-
-        try {
-            unregisterReceiver(messageReceiver);
-        } catch (IllegalArgumentException e) {}
-    }
-
     @Override
     protected void onRestart() {
         super.onRestart();
@@ -368,10 +307,10 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
     @Override
     public void onBackPressed() {
             /* Close the menu first */
-        if(mRootContainer.isDrawerOpen(mListView)) {
+        if(mDrawerLayout.isDrawerOpen(mListView)) {
             if (mFocusedPrior != 0)
                 requestFocusOnSearch();
-            mRootContainer.closeDrawer(mListView);
+            mDrawerLayout.closeDrawer(mListView);
             return;
         }
 
@@ -384,7 +323,7 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
             if (mCurrentFragment.equals(SidebarEntry.ID_NETWORK) || mCurrentFragment.equals(SidebarEntry.ID_DIRECTORIES)){
                 BaseBrowserFragment browserFragment = (BaseBrowserFragment) getSupportFragmentManager()
                         .findFragmentById(R.id.fragment_placeholder);
-                if (browserFragment !=null && !browserFragment.isRootDirectory()) {
+                if (browserFragment != null) {
                     browserFragment.goBack();
                     return;
                 }
@@ -458,7 +397,7 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
 
         if (LibVlcUtil.isFroyoOrLater()) {
             SearchManager searchManager =
-                    (SearchManager) getSystemService(Context.SEARCH_SERVICE);
+                    (SearchManager) VLCApplication.getAppContext().getSystemService(Context.SEARCH_SERVICE);
             mSearchView = (SearchView) MenuItemCompat.getActionView(menu.findItem(R.id.ml_menu_search));
             mSearchView.setSearchableInfo(searchManager.getSearchableInfo(getComponentName()));
             mSearchView.setQueryHint(getString(R.string.search_hint));
@@ -472,53 +411,57 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
 
     @Override
     public boolean onPrepareOptionsMenu (Menu menu) {
+        super.onPrepareOptionsMenu(menu);
+        if (menu == null)
+            return false;
         Fragment current = getSupportFragmentManager().findFragmentById(R.id.fragment_placeholder);
+        MenuItem item;
         // Disable the sort option if we can't use it on the current fragment.
         if (current == null || !(current instanceof ISortable)) {
-            menu.findItem(R.id.ml_menu_sortby).setEnabled(false);
-            menu.findItem(R.id.ml_menu_sortby).setVisible(false);
-        }
-        else {
+            item = menu.findItem(R.id.ml_menu_sortby);
+            if (item == null)
+                return false;
+            item.setEnabled(false);
+            item.setVisible(false);
+        } else {
             ISortable sortable = (ISortable) current;
-            menu.findItem(R.id.ml_menu_sortby).setEnabled(true);
-            menu.findItem(R.id.ml_menu_sortby).setVisible(true);
-            MenuItem item = menu.findItem(R.id.ml_menu_sortby_name);
-                if (sortable.sortDirection(VideoListAdapter.SORT_BY_TITLE) == 1)
-                    item.setTitle(R.string.sortby_name_desc);
-                else
-                    item.setTitle(R.string.sortby_name);
+            item = menu.findItem(R.id.ml_menu_sortby);
+            if (item == null)
+                return false;
+            item.setEnabled(true);
+            item.setVisible(true);
+            item = menu.findItem(R.id.ml_menu_sortby_name);
+            if (sortable.sortDirection(VideoListAdapter.SORT_BY_TITLE) == 1)
+                item.setTitle(R.string.sortby_name_desc);
+            else
+                item.setTitle(R.string.sortby_name);
             item = menu.findItem(R.id.ml_menu_sortby_length);
-                if (sortable.sortDirection(VideoListAdapter.SORT_BY_LENGTH) == 1)
-                    item.setTitle(R.string.sortby_length_desc);
-                else
-                    item.setTitle(R.string.sortby_length);
+            if (sortable.sortDirection(VideoListAdapter.SORT_BY_LENGTH) == 1)
+                item.setTitle(R.string.sortby_length_desc);
+            else
+                item.setTitle(R.string.sortby_length);
             item = menu.findItem(R.id.ml_menu_sortby_date);
-                if (sortable.sortDirection(VideoListAdapter.SORT_BY_DATE) == 1)
-                    item.setTitle(R.string.sortby_date_desc);
-                else
-                    item.setTitle(R.string.sortby_date);
+            if (sortable.sortDirection(VideoListAdapter.SORT_BY_DATE) == 1)
+                item.setTitle(R.string.sortby_date_desc);
+            else
+                item.setTitle(R.string.sortby_date);
         }
 
         boolean networkSave = current instanceof NetworkBrowserFragment && !((NetworkBrowserFragment)current).isRootDirectory();
         if (networkSave) {
-            MenuItem item = menu.findItem(R.id.ml_menu_save);
+            item = menu.findItem(R.id.ml_menu_save);
             item.setVisible(true);
             String mrl = ((BaseBrowserFragment)current).mMrl;
             item.setIcon(MediaDatabase.getInstance().networkFavExists(mrl) ?
                     R.drawable.ic_menu_bookmark_w :
                     R.drawable.ic_menu_bookmark_outline_w);
-
-        }
-        else
+        } else
             menu.findItem(R.id.ml_menu_save).setVisible(false);
         if (current instanceof MRLPanelFragment)
             menu.findItem(R.id.ml_menu_clean).setVisible(!((MRLPanelFragment) current).isEmpty());
         boolean showLast = current instanceof AudioBrowserFragment || (current instanceof VideoGridFragment && mSettings.getString(PreferencesActivity.VIDEO_LAST, null) != null);
         menu.findItem(R.id.ml_menu_last_playlist).setVisible(showLast);
-
-
-
-        return super.onPrepareOptionsMenu(menu);
+        return true;
     }
 
     /**
@@ -552,11 +495,11 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
                 break;
             // Refresh
             case R.id.ml_menu_refresh:
-                if (!MediaLibrary.getInstance().isWorking()) {
+                if (!mMediaLibrary.isWorking()) {
                     if(current != null && current instanceof IRefreshable)
                         ((IRefreshable) current).refresh();
                     else
-                        MediaLibrary.getInstance().loadMediaItems(this, true);
+                        mMediaLibrary.loadMediaItems(true);
                 }
                 break;
             // Restore last playlist
@@ -590,7 +533,7 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
                 item.setIcon(R.drawable.ic_menu_bookmark_w);
                 break;
         }
-        mRootContainer.closeDrawer(mListView);
+        mDrawerLayout.closeDrawer(mListView);
         return super.onOptionsItemSelected(item);
     }
 
@@ -599,7 +542,7 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
         super.onActivityResult(requestCode, resultCode, data);
         if (requestCode == ACTIVITY_RESULT_PREFERENCES) {
             if (resultCode == PreferencesActivity.RESULT_RESCAN)
-                MediaLibrary.getInstance().loadMediaItems(this, true);
+                mMediaLibrary.loadMediaItems(true);
             else if (resultCode == PreferencesActivity.RESULT_RESTART) {
                 Intent intent = getIntent();
                 finish();
@@ -717,21 +660,9 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
     }
 
     private void reloadPreferences() {
-        SharedPreferences sharedPrefs = getSharedPreferences("MainActivity", MODE_PRIVATE);
-        mCurrentFragment = sharedPrefs.getString("fragment", "video");
+        mCurrentFragment = mSettings.getString("fragment", "video");
     }
 
-    private final BroadcastReceiver messageReceiver = new BroadcastReceiver() {
-        @Override
-        public void onReceive(Context context, Intent intent) {
-            String action = intent.getAction();
-
-            if (action.equalsIgnoreCase(ACTION_SHOW_PLAYER)) {
-                showAudioPlayer();
-            }
-        }
-    };
-
     @Override
     public Cursor runQuery(CharSequence constraint) {
         return MediaDatabase.getInstance().queryMedia(constraint.toString());
@@ -786,7 +717,7 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
     };
 
     public void hideKeyboard(){
-        ((InputMethodManager)getSystemService(INPUT_METHOD_SERVICE)).hideSoftInputFromWindow(
+        ((InputMethodManager) VLCApplication.getAppContext().getSystemService(INPUT_METHOD_SERVICE)).hideSoftInputFromWindow(
                 getWindow().getDecorView().getRootView().getWindowToken(), 0);
     }
 
@@ -806,138 +737,17 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
         mHandler.obtainMessage(ACTIVITY_SHOW_TEXTINFO, 0, 100, null).sendToTarget();
     }
 
-    /**
-     * Show the audio player.
-     */
-    public void showAudioPlayer() {
-        mActionBar.collapseActionView();
-        // Open the pane only if is entirely opened.
-        if (mSlidingPane.getState() == mSlidingPane.STATE_OPENED_ENTIRELY)
-            mSlidingPane.openPane();
-        mAudioPlayerFilling.setVisibility(View.VISIBLE);
+    protected void onPanelClosedUiSet() {
+        mDrawerLayout.setDrawerLockMode(HackyDrawerLayout.LOCK_MODE_LOCKED_CLOSED);
     }
 
-    public int  getSlidingPaneState() {
-            return mSlidingPane.getState();
+    protected void onPanelOpenedEntirelyUiSet() {
+        mDrawerLayout.setDrawerLockMode(HackyDrawerLayout.LOCK_MODE_UNLOCKED);
     }
 
-    /**
-     * Slide down the audio player.
-     * @return true on success else false.
-     */
-    public boolean slideDownAudioPlayer() {
-        if (mSlidingPane.getState() == mSlidingPane.STATE_CLOSED) {
-            mSlidingPane.openPane();
-            return true;
-        }
-        return false;
-    }
-
-    /**
-     * Slide up and down the audio player depending on its current state.
-     */
-    public void slideUpOrDownAudioPlayer() {
-        if (mSlidingPane.getState() == mSlidingPane.STATE_CLOSED){
-            mActionBar.show();
-            mSlidingPane.openPane();
-        } else if (mSlidingPane.getState() == mSlidingPane.STATE_OPENED){
-            mActionBar.hide();
-            mSlidingPane.closePane();
-        }
-    }
-
-    /**
-     * Hide the audio player.
-     */
-    public void hideAudioPlayer() {
-        mSlidingPane.openPaneEntirely();
-        mAudioPlayerFilling.setVisibility(View.GONE);
-    }
-
-    private final SlidingPaneLayout.PanelSlideListener mPanelSlideListener
-        = new SlidingPaneLayout.PanelSlideListener() {
-        float previousOffset =  1.0f;
-            @Override
-            public void onPanelSlide(float slideOffset) {
-                if (slideOffset >= 0.1 && slideOffset > previousOffset && !mActionBar.isShowing())
-                    mActionBar.show();
-                else if (slideOffset <= 0.1 && slideOffset < previousOffset && mActionBar.isShowing())
-                    mActionBar.hide();
-                previousOffset = slideOffset;
-            }
-
-            @Override
-            public void onPanelOpened() {
-                int resId = Util.getResourceFromAttribute(MainActivity.this, R.attr.shadow_bottom_9patch);
-                if (resId != 0)
-                    mSlidingPane.setShadowResource(resId);
-                mAudioPlayer.setHeaderVisibilities(false, false, true, true, true, false);
-                mAudioPlayer.setUserVisibleHint(false);
-                mRootContainer.setDrawerLockMode(HackyDrawerLayout.LOCK_MODE_UNLOCKED);
-                removeTipViewIfDisplayed();
-                mAudioPlayer.showAudioPlayerTips();
-            }
-
-            @Override
-            public void onPanelOpenedEntirely() {
-                mAudioPlayer.setUserVisibleHint(false);
-                mSlidingPane.setShadowDrawable(null);
-                mRootContainer.setDrawerLockMode(HackyDrawerLayout.LOCK_MODE_UNLOCKED);
-            }
-
-            @Override
-            public void onPanelClosed() {
-                mAudioPlayer.setUserVisibleHint(true);
-                mAudioPlayer.setHeaderVisibilities(true, true, false, false, false, true);
-                mRootContainer.setDrawerLockMode(HackyDrawerLayout.LOCK_MODE_LOCKED_CLOSED);
-                mAudioPlayer.showPlaylistTips();
-            }
-
-    };
-
-    /**
-     * Show a tip view.
-     * @param layoutId the layout of the tip view
-     * @param settingKey the setting key to check if the view must be displayed or not.
-     */
-    public void showTipViewIfNeeded(final int layoutId, final String settingKey) {
-        if (!mSettings.getBoolean(settingKey, false) && !BuildConfig.tv) {
-            removeTipViewIfDisplayed();
-            View v = LayoutInflater.from(this).inflate(layoutId, null);
-            mRootContainer.addView(v,
-                    new HackyDrawerLayout.LayoutParams(HackyDrawerLayout.LayoutParams.MATCH_PARENT,
-                            HackyDrawerLayout.LayoutParams.MATCH_PARENT));
-
-            v.setOnClickListener(new View.OnClickListener() {
-                @Override
-                public void onClick(View v) {
-                    removeTipViewIfDisplayed();
-                }
-            });
-
-            TextView okGotIt = (TextView) v.findViewById(R.id.okgotit_button);
-            okGotIt.setOnClickListener(new View.OnClickListener() {
-                @Override
-                public void onClick(View v) {
-                    removeTipViewIfDisplayed();
-                    Editor editor = mSettings.edit();
-                    editor.putBoolean(settingKey, true);
-                    Util.commitPreferences(editor);
-                }
-            });
-        }
-    }
-
-    /**
-     * Remove the current tip view if there is one displayed.
-     */
-    public void removeTipViewIfDisplayed() {
-        if (mRootContainer.getChildCount() > 2){
-            for (int i = 0 ; i< mRootContainer.getChildCount() ; ++i){
-            if (mRootContainer.getChildAt(i).getId() == R.id.audio_tips)
-                mRootContainer.removeViewAt(i);
-            }
-        }
+    protected void onPanelOpenedUiSet() {
+        mDrawerLayout.setDrawerLockMode(HackyDrawerLayout.LOCK_MODE_UNLOCKED);
+        removeTipViewIfDisplayed();
     }
 
     @Override
@@ -948,7 +758,7 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
         if(current == null || (entry != null && current.getTag().equals(entry.id))) { /* Already selected */
             if (mFocusedPrior != 0)
                 requestFocusOnSearch();
-            mRootContainer.closeDrawer(mListView);
+            mDrawerLayout.closeDrawer(mListView);
             return;
         }
 
@@ -978,7 +788,7 @@ public class MainActivity extends AppCompatActivity implements OnItemClickListen
             showSecondaryFragment(SecondaryActivity.ABOUT);
         else if (entry.attributeID == R.attr.ic_menu_preferences)
             startActivityForResult(new Intent(this, PreferencesActivity.class), ACTIVITY_RESULT_PREFERENCES);
-        mRootContainer.closeDrawer(mListView);
+        mDrawerLayout.closeDrawer(mListView);
     }
 
     private void requestFocusOnSearch() {
