@@ -54,8 +54,8 @@ import org.videolan.vlc.MediaLibrary;
 import org.videolan.vlc.MediaWrapper;
 import org.videolan.vlc.R;
 import org.videolan.vlc.audio.AudioServiceController;
-import org.videolan.vlc.gui.SecondaryActivity;
 import org.videolan.vlc.gui.CommonDialogs;
+import org.videolan.vlc.gui.SecondaryActivity;
 import org.videolan.vlc.util.AndroidDevices;
 import org.videolan.vlc.util.Util;
 import org.videolan.vlc.util.VLCRunnable;
@@ -175,18 +175,6 @@ public class AudioAlbumsSongsFragment extends Fragment implements SwipeRefreshLa
         updateList();
     }
 
-    @Override
-    public void onResume() {
-        super.onResume();
-        AudioServiceController.getInstance().bindAudioService(getActivity());
-    }
-
-    @Override
-    public void onPause() {
-        super.onPause();
-        AudioServiceController.getInstance().unbindAudioService(getActivity());
-    }
-
     @Override
     public void onSaveInstanceState(Bundle outState) {
         outState.putParcelableArrayList("list", mMediaList);
@@ -231,16 +219,18 @@ public class AudioAlbumsSongsFragment extends Fragment implements SwipeRefreshLa
 
     private boolean handleContextItemSelected(MenuItem item, int position) {
         ContextMenuInfo menuInfo = item.getMenuInfo();
+        if (menuInfo == null)
+            return false;
 
         int startPosition;
         int groupPosition;
-        List<String> medias;
+        List<MediaWrapper> medias;
         int id = item.getItemId();
 
         boolean useAllItems = id == R.id.audio_list_browser_play_all;
         boolean append = id == R.id.audio_list_browser_append;
 
-        if (ExpandableListContextMenuInfo.class.isInstance(menuInfo)) {
+        if (menuInfo instanceof ExpandableListContextMenuInfo) {
             ExpandableListContextMenuInfo info = (ExpandableListContextMenuInfo) menuInfo;
             groupPosition = ExpandableListView.getPackedPositionGroup(info.packedPosition);
         }
@@ -250,7 +240,7 @@ public class AudioAlbumsSongsFragment extends Fragment implements SwipeRefreshLa
         if (id == R.id.audio_list_browser_delete) {
             AlertDialog alertDialog = CommonDialogs.deleteMedia(
                     getActivity(),
-                    mSongsAdapter.getLocations(groupPosition).get(0),
+                    mSongsAdapter.getMedias(groupPosition).get(0).getLocation(),
                     new VLCRunnable(mSongsAdapter.getItem(groupPosition)) {
                         @Override
                         public void run(Object o) {
@@ -272,7 +262,7 @@ public class AudioAlbumsSongsFragment extends Fragment implements SwipeRefreshLa
         }
 
         if (useAllItems) {
-            medias = new ArrayList<String>();
+            medias = new ArrayList<MediaWrapper>();
             startPosition = mSongsAdapter.getListWithPosition(medias, groupPosition);
         }
         else {
@@ -280,10 +270,10 @@ public class AudioAlbumsSongsFragment extends Fragment implements SwipeRefreshLa
             switch (mViewPager.getCurrentItem())
             {
                 case MODE_ALBUM: // albums
-                    medias = mAlbumsAdapter.getLocations(groupPosition);
+                    medias = mAlbumsAdapter.getMedias(groupPosition);
                     break;
                 case MODE_SONG: // songs
-                    medias = mSongsAdapter.getLocations(groupPosition);
+                    medias = mSongsAdapter.getMedias(groupPosition);
                     break;
                 default:
                     return true;
@@ -332,21 +322,20 @@ public class AudioAlbumsSongsFragment extends Fragment implements SwipeRefreshLa
     OnItemClickListener albumsListener = new OnItemClickListener() {
         @Override
         public void onItemClick(AdapterView<?> av, View v, int p, long id) {
-            ArrayList<MediaWrapper> mediaList = mAlbumsAdapter.getMedia(p);
+            ArrayList<MediaWrapper> mediaList = mAlbumsAdapter.getMedias(p);
             Intent i = new Intent(getActivity(), SecondaryActivity.class);
             i.putExtra("fragment", SecondaryActivity.ALBUM);
             i.putParcelableArrayListExtra("list", mediaList);
             i.putExtra("filter", mAlbumsAdapter.getTitle(p));
             startActivity(i);
-            getActivity().finish();
         }
     };
 
     OnItemClickListener songsListener = new OnItemClickListener() {
         @Override
         public void onItemClick(AdapterView<?> av, View v, int p, long id) {
-            ArrayList<String> mediaLocation = mSongsAdapter.getLocations(p);
-            mAudioController.load(mediaLocation, 0);
+            List<MediaWrapper> media = mSongsAdapter.getItem(p).mMediaList;
+            mAudioController.load(media, 0);
         }
     };
 
