@@ -22,38 +22,52 @@
  */
 package org.videolan.vlc.gui.browser;
 
+import android.net.Uri;
 import android.support.v7.widget.RecyclerView;
 import android.text.TextUtils;
 import android.view.LayoutInflater;
 import android.view.View;
 import android.view.ViewGroup;
+import android.widget.CheckBox;
 import android.widget.ImageView;
 import android.widget.TextView;
 
 import org.videolan.libvlc.Media;
+import org.videolan.vlc.MediaDatabase;
 import org.videolan.vlc.MediaWrapper;
 import org.videolan.vlc.R;
+import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.gui.audio.MediaComparators;
+import org.videolan.vlc.util.CustomDirectories;
 import org.videolan.vlc.util.Strings;
 import org.videolan.vlc.util.Util;
 
+import java.io.File;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.LinkedList;
+import java.util.List;
 
 public class BaseBrowserAdapter extends  RecyclerView.Adapter<RecyclerView.ViewHolder> {
-    private static final String TAG = "VLC/BaseBrowserAdapter";
+    protected static final String TAG = "VLC/BaseBrowserAdapter";
 
     private static final int TYPE_MEDIA = 0;
     private static final int TYPE_SEPARATOR = 1;
+    private static final int TYPE_STORAGE = 2;
 
     protected int FOLDER_RES_ID = R.drawable.ic_menu_folder;
 
     ArrayList<Object> mMediaList = new ArrayList<Object>();
     BaseBrowserFragment fragment;
+    MediaDatabase mDbManager;
+    LinkedList<String> mMediaDirsLocation;
+    List<String> mCustomDirsLocation;
+    String mEmptyDirectoryString;
 
     public BaseBrowserAdapter(BaseBrowserFragment fragment){
         this.fragment = fragment;
+        mEmptyDirectoryString = VLCApplication.getAppResources().getString(R.string.directory_empty);
     }
 
     @Override
@@ -74,64 +88,72 @@ public class BaseBrowserAdapter extends  RecyclerView.Adapter<RecyclerView.ViewH
 
     @Override
     public void onBindViewHolder(final RecyclerView.ViewHolder holder, int position) {
-        if (holder instanceof MediaViewHolder) {
-            final MediaViewHolder vh = (MediaViewHolder) holder;
-            final MediaWrapper media = (MediaWrapper) getItem(position);
-            boolean hasContextMenu = (media.getType() == MediaWrapper.TYPE_AUDIO ||
-                  media.getType() == MediaWrapper.TYPE_VIDEO ||
-                  (media.getType() == MediaWrapper.TYPE_DIR && Util.canWrite(media.getLocation())));
-            vh.title.setText(media.getTitle());
-            if (media.getDescription() != null && !TextUtils.isEmpty(media.getDescription())) {
-                vh.text.setVisibility(View.VISIBLE);
-                vh.text.setText(media.getDescription());
-            } else
-                vh.text.setVisibility(View.INVISIBLE);
-            vh.icon.setImageResource(getIconResId(media));
-            vh.more.setVisibility(hasContextMenu ? View.VISIBLE : View.GONE);
-            vh.itemView.setOnClickListener(new View.OnClickListener() {
-                @Override
-                public void onClick(View v) {
-                    MediaWrapper mw = (MediaWrapper) getItem(holder.getPosition());
-                    if (mw.getType() == MediaWrapper.TYPE_DIR)
-                        fragment.browse(mw, holder.getPosition());
-                    else {
-                        int position = 0;
-                        LinkedList<String> mediaLocations = new LinkedList<String>();
-                        MediaWrapper mediaItem;
-                        for (Object item : mMediaList)
-                            if (item instanceof MediaWrapper){
-                                mediaItem = (MediaWrapper) item;
-                                if (mediaItem.getType() == MediaWrapper.TYPE_VIDEO || mediaItem.getType() == MediaWrapper.TYPE_AUDIO) {
-                                    mediaLocations.add(mediaItem.getLocation());
-                                    if (mediaItem.equals(mw))
-                                        position = mediaLocations.size()-1;
-                                }
-                            }
-                        Util.openList(v.getContext(), mediaLocations, position);
-                    }
-                }
-            });
-            if (hasContextMenu) {
-                vh.more.setOnClickListener(new View.OnClickListener() {
-                    @Override
-                    public void onClick(View v) {
-                        fragment.onPopupMenu(vh.more, holder.getPosition());
-                    }
-                });
-                vh.itemView.setOnLongClickListener(new View.OnLongClickListener() {
-                    @Override
-                    public boolean onLongClick(View v) {
-                        fragment.mRecyclerView.openContextMenu(holder.getPosition());
-                        return true;
-                    }
-                });
-            }
+        int viewType = getItemViewType(position);
+        if (viewType == TYPE_MEDIA) {
+            onBindMediaViewHolder(holder, position);
         } else {
             SeparatorViewHolder vh = (SeparatorViewHolder) holder;
             vh.title.setText(getItem(position).toString());
         }
     }
 
+    private void onBindMediaViewHolder(final RecyclerView.ViewHolder holder, int position) {
+        final MediaViewHolder vh = (MediaViewHolder) holder;
+        final MediaWrapper media = (MediaWrapper) getItem(position);
+        boolean hasContextMenu = (media.getType() == MediaWrapper.TYPE_AUDIO ||
+                media.getType() == MediaWrapper.TYPE_VIDEO ||
+                (media.getType() == MediaWrapper.TYPE_DIR && !TextUtils.equals(media.getDescription(), mEmptyDirectoryString)));
+        vh.checkBox.setVisibility(View.GONE);
+        vh.title.setText(media.getTitle());
+        if (!TextUtils.isEmpty(media.getDescription())) {
+            vh.text.setVisibility(View.VISIBLE);
+            vh.text.setText(media.getDescription());
+        } else
+            vh.text.setVisibility(View.INVISIBLE);
+        vh.icon.setImageResource(getIconResId(media));
+        vh.more.setVisibility(hasContextMenu ? View.VISIBLE : View.GONE);
+        vh.itemView.setOnClickListener(new View.OnClickListener() {
+            @Override
+            public void onClick(View v) {
+                MediaWrapper mw = (MediaWrapper) getItem(holder.getAdapterPosition());
+                if (mw.getType() == MediaWrapper.TYPE_DIR)
+                    fragment.browse(mw, holder.getAdapterPosition());
+                else if (mw.getType() == MediaWrapper.TYPE_VIDEO)
+                    Util.openMedia(v.getContext(), mw);
+                else {
+                    int position = 0;
+                    LinkedList<MediaWrapper> mediaLocations = new LinkedList<MediaWrapper>();
+                    MediaWrapper mediaItem;
+                    for (Object item : mMediaList)
+                        if (item instanceof MediaWrapper) {
+                            mediaItem = (MediaWrapper) item;
+                            if (mediaItem.getType() == MediaWrapper.TYPE_VIDEO || mediaItem.getType() == MediaWrapper.TYPE_AUDIO) {
+                                mediaLocations.add(mediaItem);
+                                if (mediaItem.equals(mw))
+                                    position = mediaLocations.size() - 1;
+                            }
+                        }
+                    Util.openList(v.getContext(), mediaLocations, position);
+                }
+            }
+        });
+        if (hasContextMenu) {
+            vh.more.setOnClickListener(new View.OnClickListener() {
+                @Override
+                public void onClick(View v) {
+                    fragment.onPopupMenu(vh.more, holder.getAdapterPosition());
+                }
+            });
+            vh.itemView.setOnLongClickListener(new View.OnLongClickListener() {
+                @Override
+                public boolean onLongClick(View v) {
+                    fragment.mRecyclerView.openContextMenu(holder.getAdapterPosition());
+                    return true;
+                }
+            });
+        }
+    }
+
     @Override
     public int getItemCount() {
         return mMediaList.size();
@@ -139,6 +161,7 @@ public class BaseBrowserAdapter extends  RecyclerView.Adapter<RecyclerView.ViewH
 
     public class MediaViewHolder extends RecyclerView.ViewHolder {
         public TextView title;
+        public CheckBox checkBox;
         public TextView text;
         public ImageView icon;
         public ImageView more;
@@ -146,6 +169,7 @@ public class BaseBrowserAdapter extends  RecyclerView.Adapter<RecyclerView.ViewH
         public MediaViewHolder(View v) {
             super(v);
             title = (TextView) v.findViewById(R.id.title);
+            checkBox = (CheckBox) v.findViewById(R.id.browser_checkbox);
             text = (TextView) v.findViewById(R.id.text);
             icon = (ImageView) v.findViewById(R.id.dvi_icon);
             more = (ImageView) v.findViewById(R.id.item_more);
@@ -161,6 +185,37 @@ public class BaseBrowserAdapter extends  RecyclerView.Adapter<RecyclerView.ViewH
         }
     }
 
+    public static class Storage {
+        String path;
+        String name;
+        String description;
+
+        public Storage(String location){
+            path = location;
+            name = Strings.getName(path);
+        }
+
+        public String getName() {
+            return Uri.decode(name);
+        }
+
+        public void setName(String name) {
+            this.name = name;
+        }
+
+        public void setDescription(String description) {
+            this.description = description;
+        }
+
+        public String getDescription() {
+            return description;
+        }
+
+        public String getPath() {
+            return path;
+        }
+    }
+
     public void clear(){
         mMediaList.clear();
         notifyDataSetChanged();
@@ -188,6 +243,31 @@ public class BaseBrowserAdapter extends  RecyclerView.Adapter<RecyclerView.ViewH
             notifyItemInserted(position);
     }
 
+    public void setDescription(int position, String description){
+        Object item = getItem(position);
+        if (item instanceof MediaWrapper)
+            ((MediaWrapper) item).setDescription(description);
+        else if (item instanceof Storage)
+            ((Storage) item).setDescription(description);
+        else
+            return;
+        notifyItemChanged(position);
+    }
+
+    public void updateMediaDirs(){
+        if (mDbManager == null)
+            mDbManager = MediaDatabase.getInstance();
+        if (mMediaDirsLocation == null)
+            mMediaDirsLocation = new LinkedList<String>();
+        else
+            mMediaDirsLocation.clear();
+        List<File> mediaDirs = mDbManager.getMediaDirs();
+        for (File dir : mediaDirs){
+            mMediaDirsLocation.add(dir.getPath());
+        }
+        mCustomDirsLocation = Arrays.asList(CustomDirectories.getCustomDirectories());
+    }
+
     public void addAll(ArrayList<MediaWrapper> mediaList){
         mMediaList.clear();
         for (MediaWrapper mw : mediaList)
@@ -208,6 +288,8 @@ public class BaseBrowserAdapter extends  RecyclerView.Adapter<RecyclerView.ViewH
     public int getItemViewType(int position){
         if (getItem(position) instanceof  MediaWrapper)
             return TYPE_MEDIA;
+        else if (getItem(position) instanceof Storage)
+            return TYPE_STORAGE;
         else
             return TYPE_SEPARATOR;
     }
@@ -223,11 +305,17 @@ public class BaseBrowserAdapter extends  RecyclerView.Adapter<RecyclerView.ViewH
                     files.add(media);
             }
         }
-        Collections.sort(dirs, MediaComparators.byName);
-        Collections.sort(files, MediaComparators.byName);
+        if (dirs.isEmpty() && files.isEmpty())
+            return;
         mMediaList.clear();
-        mMediaList.addAll(dirs);
-        mMediaList.addAll(files);
+        if (!dirs.isEmpty()) {
+            Collections.sort(dirs, MediaComparators.byName);
+            mMediaList.addAll(dirs);
+        }
+        if (!files.isEmpty()) {
+            Collections.sort(files, MediaComparators.byName);
+            mMediaList.addAll(files);
+        }
         notifyDataSetChanged();
     }
 
