@@ -89,10 +89,10 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
     public String mMrl;
     protected MediaWrapper mCurrentMedia;
     protected int mSavedPosition = -1, mFavorites = 0;
-    protected boolean mRoot;
+    public boolean mRoot;
     protected LibVLC mLibVLC;
 
-    private SparseArray<ArrayList<MediaWrapper>> mMediaLists;
+    private SparseArray<ArrayList<MediaWrapper>> mMediaLists = new SparseArray<ArrayList<MediaWrapper>>();
     private ArrayList<MediaWrapper> mediaList;
     public int mCurrentParsedPosition = 0;
 
@@ -125,14 +125,14 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
     }
 
     public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState){
-        View v = inflater.inflate(R.layout.network_browser, container, false);
+        View v = inflater.inflate(R.layout.directory_browser, container, false);
         mRecyclerView = (ContextMenuRecyclerView) v.findViewById(R.id.network_list);
         mEmptyView = (TextView) v.findViewById(android.R.id.empty);
         mLayoutManager = new LinearLayoutManager(getActivity());
         mRecyclerView.addItemDecoration(new DividerItemDecoration(getActivity(), DividerItemDecoration.VERTICAL_LIST));
         mRecyclerView.setLayoutManager(mLayoutManager);
         mRecyclerView.setAdapter(mAdapter);
-        mRecyclerView.setOnScrollListener(mScrollListener);
+        mRecyclerView.addOnScrollListener(mScrollListener);
         registerForContextMenu(mRecyclerView);
 
         mSwipeRefreshLayout = (SwipeRefreshLayout) v.findViewById(R.id.swipeLayout);
@@ -179,7 +179,10 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
     }
 
     public void goBack(){
-        getActivity().getSupportFragmentManager().popBackStack();
+        if (!mRoot)
+            getActivity().getSupportFragmentManager().popBackStack();
+        else
+            getActivity().finish();
     }
 
     public void browse (MediaWrapper media, int position){
@@ -196,10 +199,9 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         ft.commit();
     }
 
-
     @Override
     public void onMediaAdded(int index, Media media) {
-        mAdapter.addItem(media, mReadyToDisplay && mRoot, true);
+        mAdapter.addItem(media, mReadyToDisplay && mRoot, mRoot);
         if (mReadyToDisplay)
             updateEmptyView();
         if (mRoot)
@@ -337,19 +339,27 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         setContextMenu(getActivity().getMenuInflater(), menu, info.position);
     }
 
-    private void setContextMenu(MenuInflater inflater, Menu menu, int position) {
+    protected void setContextMenu(MenuInflater inflater, Menu menu, int position) {
         MediaWrapper mw = (MediaWrapper) mAdapter.getItem(position);
-        boolean canWrite = Util.canWrite(mw.getLocation());
         if (mw.getType() == MediaWrapper.TYPE_AUDIO || mw.getType() == MediaWrapper.TYPE_VIDEO) {
+            boolean canWrite = Util.canWrite(mw.getLocation());
             inflater.inflate(R.menu.directory_view_file, menu);
             menu.findItem(R.id.directory_view_delete).setVisible(canWrite);
         } else if (mw.getType() == MediaWrapper.TYPE_DIR) {
-            if (canWrite) {
+            boolean isEmpty = mMediaLists.get(position) == null || mMediaLists.get(position).isEmpty();
+            if (/*canWrite || */!isEmpty) {
                 inflater.inflate(R.menu.directory_view_dir, menu);
-                boolean nomedia = new File(mw.getLocation() + "/.nomedia").exists();
-                menu.findItem(R.id.directory_view_hide_media).setVisible(!nomedia);
-                menu.findItem(R.id.directory_view_show_media).setVisible(nomedia);
+//                if (canWrite) {
+//                    boolean nomedia = new File(mw.getLocation() + "/.nomedia").exists();
+//                    menu.findItem(R.id.directory_view_hide_media).setVisible(!nomedia);
+//                    menu.findItem(R.id.directory_view_show_media).setVisible(nomedia);
+//                } else {
+//                    menu.findItem(R.id.directory_view_hide_media).setVisible(false);
+//                    menu.findItem(R.id.directory_view_show_media).setVisible(false);
+//                }
+                menu.findItem(R.id.directory_view_play_folder).setVisible(!isEmpty);
             }
+
         }
     }
 
@@ -381,7 +391,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
         popupMenu.show();
     }
 
-    private boolean handleContextItemSelected(MenuItem item, int position) {
+    protected boolean handleContextItemSelected(MenuItem item, int position) {
         int id = item.getItemId();
         if (! (mAdapter.getItem(position) instanceof MediaWrapper))
             return super.onContextItemSelected(item);
@@ -391,7 +401,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
                 Util.openMedia(getActivity(), (MediaWrapper) mAdapter.getItem(position));
                 return true;
             case R.id.directory_view_append:
-                AudioServiceController.getInstance().append(mw.getLocation());
+                AudioServiceController.getInstance().append(mw);
                 return true;
             case R.id.directory_view_delete:
                 AlertDialog alertDialog = CommonDialogs.deleteMedia(getActivity(), mw.getLocation(),
@@ -404,26 +414,34 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
                 alertDialog.show();
                 return true;
             case R.id.directory_view_play_audio:
-                AudioServiceController.getInstance().load(mw.getLocation());
+                AudioServiceController.getInstance().load(mw);
                 return true;
             case  R.id.directory_view_play_video:
                 VideoPlayerActivity.start(getActivity(), mw.getLocation());
                 return true;
-            case R.id.directory_view_hide_media:
-                try {
-                    new File(mw.getLocation()+"/.nomedia").createNewFile();
-                    updateLib();
-                } catch (IOException e) {}
-                return true;
-            case R.id.directory_view_show_media:
-                new File(mw.getLocation()+"/.nomedia").delete();
-                updateLib();
+            case R.id.directory_view_play_folder:
+                ArrayList<MediaWrapper> mediaList = new ArrayList<MediaWrapper>();
+                for (MediaWrapper mediaItem : mMediaLists.get(position)){
+                    if (mediaItem.getType() == MediaWrapper.TYPE_AUDIO || mediaItem.getType() == MediaWrapper.TYPE_VIDEO)
+                        mediaList.add(mediaItem);
+                }
+                Util.openList(getActivity(), mediaList, 0);
                 return true;
+//            case R.id.directory_view_hide_media:
+//                try {
+//                    if (new File(mw.getLocation()+"/.nomedia").createNewFile())
+//                        updateLib();
+//                } catch (IOException e) {}
+//                return true;
+//            case R.id.directory_view_show_media:
+//                if (new File(mw.getLocation()+"/.nomedia").delete())
+//                    updateLib();
+//                return true;
         }
         return false;
     }
 
-    private void updateLib() {
+    protected void updateLib() {
         FragmentManager fm = getFragmentManager();
         FragmentTransaction ft = fm.beginTransaction();
         Fragment fragment = fm.findFragmentByTag(SidebarAdapter.SidebarEntry.ID_AUDIO);
@@ -444,17 +462,23 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
     protected void parseSubDirectories() {
         if (mCurrentParsedPosition == -1 || mAdapter.isEmpty())
             return;
-        mMediaLists = new SparseArray<ArrayList<MediaWrapper>>();
+        mMediaLists.clear();
         mMediaBrowser.changeEventListener(mFoldersBrowserListener);
         mCurrentParsedPosition = 0;
         Object item;
         MediaWrapper mw;
         while (mCurrentParsedPosition <mAdapter.getItemCount()){
             item = mAdapter.getItem(mCurrentParsedPosition);
-            if (item instanceof MediaWrapper){
+            if (item instanceof BaseBrowserAdapter.Storage) {
+                mw = new MediaWrapper(((BaseBrowserAdapter.Storage) item).getPath());
+                mw.setType(MediaWrapper.TYPE_DIR);
+            } else  if (item instanceof MediaWrapper){
                 mw = (MediaWrapper) item;
+            } else
+                mw = null;
+            if (mw != null){
                 if (mw.getType() == MediaWrapper.TYPE_DIR || mw.getType() == MediaWrapper.TYPE_PLAYLIST){
-                    mMediaBrowser.browse(((MediaWrapper) mAdapter.getItem(mCurrentParsedPosition)).getLocation());
+                    mMediaBrowser.browse(mw.getLocation());
                     return;
                 }
             }
@@ -486,27 +510,32 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
                 return;
             }
             String holderText = getDescription(directories.size(), files.size());
-            MediaWrapper mw = (MediaWrapper) mAdapter.getItem(mCurrentParsedPosition);
+            MediaWrapper mw = null;
 
             if (!TextUtils.equals(holderText, "")) {
-                mw.setDescription(holderText);
-                mAdapter.notifyItemChanged(mCurrentParsedPosition);
+                mAdapter.setDescription(mCurrentParsedPosition, holderText);
                 directories.addAll(files);
-                mMediaLists.append(mCurrentParsedPosition, directories);
+                mMediaLists.put(mCurrentParsedPosition, new ArrayList<MediaWrapper>(directories));
             }
-            while (++mCurrentParsedPosition < mAdapter.getItemCount()-1){ //skip media that are not browsable
+            while (++mCurrentParsedPosition < mAdapter.getItemCount()){ //skip media that are not browsable
                 if (mAdapter.getItem(mCurrentParsedPosition) instanceof MediaWrapper) {
                     mw = (MediaWrapper) mAdapter.getItem(mCurrentParsedPosition);
                     if (mw.getType() == MediaWrapper.TYPE_DIR || mw.getType() == MediaWrapper.TYPE_PLAYLIST)
                         break;
-                }
+                } else if (mAdapter.getItem(mCurrentParsedPosition) instanceof BaseBrowserAdapter.Storage) {
+                    mw = new MediaWrapper(((BaseBrowserAdapter.Storage) mAdapter.getItem(mCurrentParsedPosition)).getPath());
+                    break;
+                } else
+                    mw = null;
             }
 
-            if (mCurrentParsedPosition < mAdapter.getItemCount()) {
-                mMediaBrowser.browse(((MediaWrapper) mAdapter.getItem(mCurrentParsedPosition)).getLocation());
-            } else {
-                mCurrentParsedPosition = -1;
-                mMediaBrowser.release();
+            if (mw != null) {
+                if (mCurrentParsedPosition < mAdapter.getItemCount()) {
+                    mMediaBrowser.browse(mw.getLocation());
+                } else {
+                    mCurrentParsedPosition = -1;
+                    mMediaBrowser.release();
+                }
             }
             directories .clear();
             files.clear();
