@@ -20,26 +20,6 @@
 
 package org.videolan.vlc.util;
 
-import java.io.BufferedReader;
-import java.io.Closeable;
-import java.io.File;
-import java.io.IOException;
-import java.io.InputStream;
-import java.io.InputStreamReader;
-import java.util.List;
-import java.util.concurrent.atomic.AtomicInteger;
-
-import org.videolan.libvlc.LibVLC;
-import org.videolan.libvlc.LibVlcUtil;
-import org.videolan.libvlc.Media;
-import org.videolan.vlc.MediaWrapper;
-import org.videolan.vlc.MediaLibrary;
-import org.videolan.vlc.R;
-import org.videolan.vlc.VLCApplication;
-import org.videolan.vlc.VLCCallbackTask;
-import org.videolan.vlc.audio.AudioServiceController;
-import org.videolan.vlc.gui.video.VideoPlayerActivity;
-
 import android.annotation.TargetApi;
 import android.content.ContentResolver;
 import android.content.Context;
@@ -50,7 +30,6 @@ import android.content.pm.ResolveInfo;
 import android.content.res.TypedArray;
 import android.net.Uri;
 import android.os.Build;
-import android.os.Environment;
 import android.provider.MediaStore;
 import android.text.TextUtils.TruncateAt;
 import android.util.DisplayMetrics;
@@ -58,6 +37,26 @@ import android.util.TypedValue;
 import android.widget.TextView;
 import android.widget.Toast;
 
+import org.videolan.libvlc.LibVLC;
+import org.videolan.libvlc.LibVlcUtil;
+import org.videolan.libvlc.Media;
+import org.videolan.vlc.MediaLibrary;
+import org.videolan.vlc.MediaWrapper;
+import org.videolan.vlc.R;
+import org.videolan.vlc.VLCApplication;
+import org.videolan.vlc.VLCCallbackTask;
+import org.videolan.vlc.audio.AudioServiceController;
+import org.videolan.vlc.gui.video.VideoPlayerActivity;
+
+import java.io.BufferedReader;
+import java.io.Closeable;
+import java.io.File;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.InputStreamReader;
+import java.util.List;
+import java.util.concurrent.atomic.AtomicInteger;
+
 public class Util {
     private static final AtomicInteger sNextGeneratedId = new AtomicInteger(1);
     public static final String ACTION_SCAN_START = "org.videolan.vlc.gui.ScanStart";
@@ -207,11 +206,19 @@ public class Util {
         String mrl = media.getLocation();
         if (media.getType() == MediaWrapper.TYPE_VIDEO)
             VideoPlayerActivity.start(context, mrl, media.getTitle());
-        else if (media.getType() == MediaWrapper.TYPE_AUDIO)
-            openStream(context, mrl);
+        else if (media.getType() == MediaWrapper.TYPE_AUDIO) {
+            VLCCallbackTask task = new VLCCallbackTask(context) {
+                @Override
+                public void run() {
+                    AudioServiceController c = AudioServiceController.getInstance();
+                    c.load(media);
+                }
+            };
+            task.execute();
+        }
     }
 
-    public static  void openList(Context context, final List<String> list, final int position){
+    public static  void openList(Context context, final List<MediaWrapper> list, final int position){
         VLCCallbackTask task = new VLCCallbackTask(context){
             @Override
             public void run() {
@@ -241,7 +248,7 @@ public class Util {
                        * (for example, RTSP and TS streaming) where ES can be
                        * dynamically adapted rather than a simple scan.
                        */
-                c.load(uri);
+                c.loadLocation(uri);
             }
         };
         task.execute();
@@ -348,7 +355,7 @@ public class Util {
             path = path.substring(7);
         if (!path.startsWith("/"))
             return false;
-        if (path.startsWith(Environment.getExternalStorageDirectory().getPath()))
+        if (path.startsWith(AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY))
             return true;
         if (LibVlcUtil.isLolliPopOrLater())
             return false;
