@@ -2,6 +2,7 @@
  * GridFragment.java
  *****************************************************************************
  * Copyright © 2014-2015 VLC authors, VideoLAN and VideoLabs
+ * Author: Geoffrey Métais
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +37,7 @@ public class GridFragment extends VerticalGridFragment {
 
     public interface BrowserActivity {
         public void showProgress(boolean show);
+        public void updateEmptyView(boolean empty);
     }
 
     protected static final String TAG = "VLC/GridFragment";
@@ -64,7 +66,4 @@ public class GridFragment extends VerticalGridFragment {
             TvUtil.openMedia(getActivity(), item, null);
         }
     };
-
-
-
 }
\ No newline at end of file
